@@ -2698,6 +2698,12 @@ sunone_connection_storetodos (SunOneConnection *connection, const char *calid, i
 	if (num) {
 		append_to_query_int (fetch_uri, "percent", *num);
 		e_cal_component_free_percent (num);
+	} else {
+		/*When one marks a completed task as uncompleted, evolution will remove
+		 *percent property, this would cause problem on some calendar servers,
+		 *so we need to set percent property to 0
+		 */
+		append_to_query_int (fetch_uri, "percent", 0);
 	}
 	
 	/* Priority */
