@@ -32,7 +32,7 @@
 #include "sunone-component.h"
 #include "sunone-offline-listener.h"
 
-#define CLEAN_WCAP 1
+#define CLEAN_WCAP 0
 
 static EDataCalFactory *calendar_factory = NULL;
 char *evolution_dir;
@@ -70,7 +70,7 @@ static gboolean
 setup_calendar (void)
 {	
 	/* setup calendar factory */
-	g_print ("Setting up calendar factory...\n");
+	g_message ("Setting up calendar factory...\n");
 	calendar_factory = e_data_cal_factory_new ();
 	if (!calendar_factory) {
 		g_warning ("\nCould not create the calendar factory\n");
@@ -152,7 +152,7 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	g_print ("Initializing evolution-jescs...\n");
+	g_message ("Initializing evolution-jescs...\n");
 
 	g_thread_init (NULL);
 
@@ -194,7 +194,7 @@ main (int argc, char *argv[])
 					offline_listener);
 
 	/* run the application */
-	g_print ("Evolution-jescs up and running!\n");
+	g_message ("Evolution-jescs up and running!\n");
 	if (getenv ("EVOLUTION_JESCS_VERBOSE_DEBUG")) {
                 /* Redirect stderr to stdout and make it line-buffered
                  * rather than block-buffered, for ease of debug
